@@ -22,29 +22,28 @@
 #include <config.h>
 #endif
 
+#include "httphandler.h"
+#include "logfile.h"
+#include "params.h"
+#include "default.h"
+
 #include <iostream>
 #include <algorithm>
 #include <string>
-
+#include <map>
 #include <stdarg.h>
 #include <stdio.h>
 
 using namespace std; 
 
-#include "httphandler.h"
-
-
 class ConnectionToBrowser : public HTTPHandler  {
 
 private:
 
-string Request;
-
-string Host;
+map <string,string> URLRewrite;
 
 int Port;
 
-
 vector <string> Methods;
 
 string RequestType;
@@ -60,12 +59,16 @@ public:
 string PrepareHeaderForServer();
 
 const char *GetHost();
+const string GetRequest();
 
 const char *GetCompleteRequest();
 
+const string GetRequestType();
+
 int GetPort();
 
-      
+bool RewriteHost();
+
 	ConnectionToBrowser();
 	~ConnectionToBrowser();
 };
